import gradio as gr
from transformers import pipeline
from gradio.themes.utils import sizes


theme = gr.themes.Default(radius_size=sizes.radius_none).set(
    block_label_text_color = '#4D63FF',
    block_title_text_color = '#4D63FF',
    button_primary_text_color = '#4D63FF',
    button_primary_background_fill='#FFFFFF',
    button_primary_border_color='#4D63FF',
    button_primary_background_fill_hover='#EDEFFF',
)



unmasker = pipeline('fill-mask', model='bert-base-uncased')

def fill_masker(text):
    results = unmasker(text)
    total_results = ""

    for result in results:
        total_results += f"Token: {result.get('token_str')}, Score: {result.get('score')}"
        total_results += '\r\n'

    return total_results


with gr.Blocks(theme=theme, css="footer {visibility: hidden}") as demo:
    with gr.Row():
        with gr.Column():
            box1 = gr.Textbox(label="文本")
            with gr.Row():
                button = gr.Button("提交", variant="primary")
                clear = gr.Button("清除", variant="primary")
        box2 = gr.Textbox(label="文本")

    button.click(fn=fill_masker, inputs=box1, outputs=box2)
    clear.click(lambda x: gr.update(value=''), [], [box1])
    examples = gr.Examples(examples=[['Paris is the [MASK] of France.'], ['The goal of life is [MASK].']],  inputs=[box1], label="例子")


if __name__ == "__main__":
    demo.queue(concurrency_count=3)
    demo.launch(server_name = "0.0.0.0", server_port = 7028)
